.onAttach <- function(...){
	packageStartupMessage("Much appreciate for using CMplot.")
    packageStartupMessage("Full description, Bug report, Suggestion and the latest codes:")
    packageStartupMessage("https://github.com/YinLiLin/CMplot")
}
